@@ -334,13 +334,16 @@ void MainWindow::filter(void) {
       m_ui.title_edit->setText("");
     };
     if (!m_ui.category_edit->text().isEmpty()) {
-      m_database.select_by_category(m_ui.category_edit->text().toUtf8().constData());
+      if (m_ui.with_category_radio->isChecked())
+        m_database.select_by_category(m_ui.category_edit->text().toUtf8().constData());
+      else
+        m_database.select_by_no_category(m_ui.category_edit->text().toUtf8().constData());
       m_titles_model->reset();
       m_categories_model->reset();
       m_ui.category_edit->setText("");
     };
     if (!m_ui.ingredient_edit->text().isEmpty()) {
-      if (m_ui.with_radio->isChecked())
+      if (m_ui.with_ingredient_radio->isChecked())
         m_database.select_by_ingredient(m_ui.ingredient_edit->text().toUtf8().constData());
       else
         m_database.select_by_no_ingredient(m_ui.ingredient_edit->text().toUtf8().constData());
